"""Market bot module"""

from datetime import datetime, timedelta

from rival_regions_wrapper.wrapper import Storage

from rival_regions_marketbot import RR_WRAPPER, PROFILE_ID, SCHEDULER, wrapper


MARKET_MAX = {
    "helium-3": 153600,
    "liquid_oxygen": 38400000,
    "oil": 614400000,
    "ore": 614400000,
    "uranium": 15360000,
    "diamonds": 153600,
    "rivalium": 614400,
    "antirad": 76800,
    "spacerockets": 3840,
    "lss": 15360000,
    "tanks": 4388571,
    "aircrafts": 640000,
    "missiles": 256000,
    "bombers": 128000,
    "battleships": 128000,
    "laser_drones": 256000,
    "moon_tanks": 12800,
    "space_stations": 1280,
}


class MarketBot:
    """Market bot class"""

    item = None
    minimum_sell_price = None
    maximum_buy_price = None

    def __init__(self, item, minimum_sell_price, maximum_buy_price):
        self.item = item
        self.miniumum_sell_price = minimum_sell_price
        self.maximum_buy_price = maximum_buy_price

    def start_jobs(self):
        """Start jobs"""
        SCHEDULER.add_job(
            buy,
            "date",
            run_date=datetime.now() + timedelta(minutes=5),
            id="buy_{}".format(self.item),
            args=[self.item, self.minimum_sell_price],
        )
        SCHEDULER.add_job(
            sell,
            "date",
            run_date=datetime.now() + timedelta(minutes=5),
            id="sell_{}".format(self.item),
            args=[self.item, self.minimum_sell_price],
        )

def sell(item, minimum_sell_price):
    """Market bot sell method"""
    market = wrapper.Market(RR_WRAPPER)
    first_offer = market.first_offer(item)
    if first_offer["profile_id"] != PROFILE_ID:
        # op_markt = market.offer_by(item, PROFILE_ID)
        # totaal = Storage(RR_WRAPPER).info()[item]
        # totaal = opslag + op_markt
        totaal = min(
            Storage(RR_WRAPPER).info()[item], MARKET_MAX[item]
        )
        price = max(
            minimum_sell_price,
            (first_offer["price"] * 100 - 10) / 100,
        )
        # if totaal == op_markt and own_price == minimum_price:
        if totaal != 0:
            market.sell(
                {
                    "item": item,
                    "amount": totaal,
                    "price": price,
                }
            )

def buy(item, maximum_buy_price):
    """Market bot buy method"""
    market = wrapper.Market(RR_WRAPPER)
    offer = market.first_offer(item)
    if offer["price"] <= maximum_buy_price:
        market.buy(offer)

if __name__ == "__main__":
    sell.__module__ = "marketbot"
    buy.__module__ = "marketbot"
